%TEST1D test script for 1D integral approximation

%   P. Diaz de Alba, L. Fermo, and G. Rodriguez
%   University of Cagliari, Italy
%
%   Last revised April 16, 2025

%% Test function
examp = 2;  % test function from fun1D.m

%% Number of nodes
p = 1:8;
n = 2.^p;
ln = length(n);

%% Parameters for the Jacobi weight
alpha = 0;
beta = 0;

%% Reference value of the integral
[x,lambda] = nodesweights(512,alpha,beta);
f = fun1D(examp,x);
Iexact = lambda'*f;

%% Tables with approximation value and errors
c1 = zeros(ln,1);
c2 = zeros(ln,1);

Gn = zeros(ln,1);
antiGn = zeros(ln,1);
GSn = zeros(ln,1);
avGn = zeros(ln,1);
avGnGSn = zeros(ln,1);

errg = zeros(ln,1);
errag = zeros(ln,1);
errgs = zeros(ln,1);
errav = zeros(ln,1);
erravgs = zeros(ln,1);

stimerr = zeros(ln,1);
stimerrs = zeros(ln,1);

% Table for approximation value
fprintf('\nIntegral approximations \n')
fprintf('m \t Gauss \t\t anti-Gauss \t G^* \t\t Average \t Average G^* \n')
fprintf('---------------------------------------------------------------------------------------\n')
for i=1:ln
	Gn(i) = quadG1D(examp,n(i),alpha,beta);
	antiGn(i) = quadantiG1D(examp,n(i),alpha,beta);
	[GSn(i),c1(i),c2(i)] = quadGS1D(examp,n(i),alpha,beta);
	avGn(i) = (Gn(i)+antiGn(i))./2;
	avGnGSn(i) = c1(i)*Gn(i)+c2(i)*GSn(i);
	fprintf('%d \t %.10f \t %.10f \t %.10f \t %.10f \t %.10f',n(i),Gn(i),antiGn(i),GSn(i),avGn(i),avGnGSn(i))
	fprintf('\n')
end
fprintf('---------------------------------------------------------------------------------------\n')

% Table for errors
fprintf('\nAbsolute errors \n')
fprintf('m \t Gauss \t\t anti-Gauss \t G^* \t\t Average \t Average G^* \t Estimate \t Estimate G^* \n')
fprintf('---------------------------------------------------------------------------------------------------------------------\n')
for i=1:ln
	errg(i) = Iexact-Gn(i);
	errag(i) = Iexact-antiGn(i);
	errgs(i) = Iexact-GSn(i);
	errav(i) = Iexact-avGn(i);
	erravgs(i) = Iexact-avGnGSn(i);
	stimerr(i) = (1/2)*(antiGn(i)-Gn(i));
	stimerrs(i) = c2(i)*(GSn(i)-Gn(i));
	fprintf('%d \t %+.2e \t %+.2e \t %+.2e \t %+.2e \t %+.2e \t %+.2e \t %+.2e',n(i),errg(i),errag(i),errgs(i),errav(i),erravgs(i),stimerr(i),stimerrs(i))
	fprintf('\n')
end
fprintf('---------------------------------------------------------------------------------------------------------------------\n')

